Probability
==============

Random variables are the main objects in ProbNum. They represent uncertainty about a numerical quantity via their
distribution. A probabilistic numerical method takes random variables as inputs and also outputs random variables.

See the notebooks below to learn more about how to use and manipulate probabilistic quantities in ProbNum.


.. nbgallery::
   :maxdepth: 2

   probability/random_variables


----

You can also interactively try out the |Tutorials| directly in the browser or
by downloading the notebooks from the
`GitHub repository <https://github.com/probabilistic-numerics/probnum/tree/master/docs/source/tutorials>`_.

.. |Tutorials| image:: https://img.shields.io/badge/Tutorials-Jupyter-579ACA.svg?&logo=Jupyter&logoColor=white
    :target: https://mybinder.org/v2/gh/probabilistic-numerics/probnum/master?filepath=docs%2Fsource%2Ftutorials
    :alt: ProbNum's Tutorials
